Please check these boxes before submitting your issue, thank you!

 - [ ] aiida-vasp and aiida-core are installed in a virtualenv that is used for nothing else
 - [ ] if you are installing from the repo: pull the latest changes aiida-core and aiida-vasp
 - [ ] remove all *.pyc files and restart the daemon, then retry

## Environment
 * Operating system:
 * aiida-core version/branch+commit:
 * aiida-vasp version/branch+commit:

## Steps that lead to the error

## What should happen

## What happened instead
